--- title: "wallaroo.records.convert_keras_model" type: docs linkTitle: "wallaroo.records.convert_keras_model" ---
def from_bool(x: Any) -> bool:
def from_none(x: Any) -> Any:
def from_union(fs, x):
def from_int(x: Any) -> int:
def to_class(c: Type[~T], x: Any) -> dict:
def from_str(x: Any) -> str:
def from_list(f: Callable[[Any], ~T], x: Any) -> List[~T]:
class ConvertKerasMutation:
ConvertKerasMutation(ok: Optional[bool], model: int)
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.convert_keras_model.ConvertKerasMutation:
def to_dict(self) -> dict:
class Data:
Data( convert_keras: Optional[wallaroo.records.convert_keras_model.ConvertKerasMutation])
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.convert_keras_model.Data:
def to_dict(self) -> dict:
class Error:
Error(message: str)
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.convert_keras_model.Error:
def to_dict(self) -> dict:
class ConvertKerasModel:
ConvertKerasModel( data: Optional[wallaroo.records.convert_keras_model.Data], errors: Optional[List[wallaroo.records.convert_keras_model.Error]])
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.convert_keras_model.ConvertKerasModel:
def to_dict(self) -> dict:
def convert_keras_model_from_dict(s: Any) -> wallaroo.records.convert_keras_model.ConvertKerasModel:
def convert_keras_model_to_dict(x: wallaroo.records.convert_keras_model.ConvertKerasModel) -> Any: